aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Target/TargetAsmInfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Target/TargetAsmInfo.h')
-rw-r--r--include/llvm/Target/TargetAsmInfo.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/llvm/Target/TargetAsmInfo.h b/include/llvm/Target/TargetAsmInfo.h
index cb0e346..4f8d92b 100644
--- a/include/llvm/Target/TargetAsmInfo.h
+++ b/include/llvm/Target/TargetAsmInfo.h
@@ -1,4 +1,4 @@
-//===-- llvm/Target/TargetAsmInfo.h - Asm info ------------------*- C++ -*-===//
+//===-- llvm/MC/MCAsmInfo.h - Asm info --------------------------*- C++ -*-===//
//
// The LLVM Compiler Infrastructure
//
@@ -23,11 +23,11 @@
namespace llvm {
template <typename T> class SmallVectorImpl;
/// TargetAsmInfo - This class is intended to be used as a base class for asm
/// properties and features specific to the target.
namespace ExceptionHandling { enum ExceptionsType { None, Dwarf, SjLj }; }
- class TargetAsmInfo {
+ class MCAsmInfo {
protected:
//===------------------------------------------------------------------===//
// Properties to be set by the target writer, used to configure asm printer.
@@ -310,8 +310,8 @@ namespace llvm {
const char *const *AsmTransCBE; // Defaults to empty
public:
- explicit TargetAsmInfo();
- virtual ~TargetAsmInfo();
+ explicit MCAsmInfo();
+ virtual ~MCAsmInfo();
/// getSLEB128Size - Compute the number of bytes required for a signed
/// leb128 value.
@@ -23,11 +23,11 @@
namespace llvm {
template <typename T> class SmallVectorImpl;
- /// TargetAsmInfo - This class is intended to be used as a base class for asm
+ /// MCAsmInfo - This class is intended to be used as a base class for asm
/// properties and features specific to the target.
namespace ExceptionHandling { enum ExceptionsType { None, Dwarf, SjLj }; }